# Dogs vs. Cats Kaggle's competition project (inference)

This project brings an usable simple solution for the Kaggle's competition dogs-vs-cats (https://www.kaggle.com/c/dogs-vs-cats). Training project can be found at https://github.com/albertoburgosplaza/dogs-vs-cats.

## Quick start

```python
from dogsvscats.predict import predict
predict(<image_path>)
```
Check the Colab notebook:

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1hQb7MSMVfAIKJ8Yr-_r6BWLX8LEKwVWd?usp=sharing)
